==> MPBS-0.0.2.8.tar.gz: MPBS-0.0.2.8/MPBS/core/base.py <==
#coding=utf-8
'''
Created on 2016年3月3日
'''
import zmq
from exception import UnimplementedException, MPBS404
import logging
__author__ = 'chenjian'

class Application(object):
    '''
    classdocs
    '''


    def __init__(self, *args, **kwargs):
        '''
        Constructor
        '''
        
        self.handlers = dict()
        for uri, hdr in kwargs['handlers']:
            uri = '/%s/'% uri.strip('/')
            if uri == '//': uri = '/'
            self.handlers[uri] = hdr

class MPBSServer(object):
    '''
    '''
    
    def __init__(self, application, addr):
        self.application = application
        self.addr = addr
        
    def start(self):
        '''
        '''
        
        context = zmq.Context()
        subscriber = context.socket(zmq.SUB)  # @UndefinedVariable
        subscriber.connect(self.addr)
        subscriber.setsockopt(zmq.SUBSCRIBE, b"")  # @UndefinedVariable

        while True:
            try:
                [uri, headers, body] = subscriber.recv_multipart()
                
                uri = '/%s/'% uri.strip('/')
                if uri == '//': uri = '/'
                handler_cls = self.application.handlers[uri]
                
                if not handler_cls:
                    raise MPBS404()
                
                # request对象
                request = Request(uri=uri, headers=headers, body=body)
                # 实例化handler
                handler = handler_cls(application=self.application, request=request)
                # handle
                handler.handle()
            except Exception, e:
                logging.exception(e)
            
class Request(object):
    '''
    '''
    
    def __init__(self, **kwargs):
        '''
        '''
        
        self.uri = kwargs['uri']
        self.headers = kwargs['headers']
        self.body = kwargs['body']
        
class MPBSHandler(object):
    '''
    '''
    
    def __init__(self, *args, **kwargs):
        '''
        '''
        
        self.application = kwargs['application']
        self.request = kwargs['request']
        
    def handle(self):
        '''
        '''
        
        raise UnimplementedException()

==> MPBS-0.0.3.2.tar.gz: MPBS-0.0.3.2/MPBS/core/base.py <==
#coding=utf-8
'''
Created on 2016年3月3日
'''
import zmq
from exception import UnimplementedException, MPBS404
import logging
__author__ = 'chenjian'

class Application(object):
    '''
    classdocs
    '''


    def __init__(self, *args, **kwargs):
        '''
        Constructor
        '''
        
        self.handlers = dict()
        for uri, hdr in kwargs['handlers']:
            uri = '/%s/'% uri.strip('/')
            if uri == '//': uri = '/'
            self.handlers[uri] = hdr

class MPBSServer(object):
    '''
    '''
    
    def __init__(self, application, addr):
        self.application = application
        self.addr = addr
        
    def start(self):
        '''
        '''
        
        context = zmq.Context()
        subscriber = context.socket(zmq.SUB)  # @UndefinedVariable
        subscriber.connect(self.addr)
        subscriber.setsockopt(zmq.SUBSCRIBE, b"")  # @UndefinedVariable

        while True:
            try:
                [uri, headers, body] = subscriber.recv_multipart()
                
                uri = '/%s/'% uri.strip('/')
                if uri == '//': uri = '/'
                handler_cls = self.application.handlers[uri]
                
                if not handler_cls:
                    raise MPBS404()
                
                # request对象
                request = Request(uri=uri, headers=headers, body=body)
                # 实例化handler
                handler = handler_cls(application=self.application, request=request)
                # handle
                handler.handle()
            except Exception, e:
                logging.exception(e)
            
class Request(object):
    '''
    '''
    
    def __init__(self, **kwargs):
        '''
        '''
        
        self.uri = kwargs['uri']
        self.headers = kwargs['headers']
        self.body = kwargs['body']
        
class MPBSHandler(object):
    '''
    '''
    
    def __init__(self, application, request, **kwargs):
        '''
        '''
        
        self.application = application
        self.request = request
        
    def handle(self):
        '''
        '''
        
        raise UnimplementedException()
